---
name: 🤖 Claude Code Assistance
about: Request Claude AI assistance for code issues, features, or debugging
title: '[CLAUDE] '
labels: 'claude-assistance, needs-claude'
assignees: ''
---

## 🤖 Claude Code Assistance Request

**Request Type**: 
- [ ] Bug Investigation & Fix
- [ ] Feature Implementation
- [ ] Code Review & Analysis
- [ ] Debugging & Troubleshooting
- [ ] Documentation Enhancement
- [ ] Performance Optimization
- [ ] Test Coverage Improvement

## 📝 Task Description

### What needs to be done?
<!-- Provide a clear description of what you want Claude to help with -->

### Context & Background
<!-- Provide relevant context about the codebase, feature, or issue -->

### Expected Outcome
<!-- What should the end result look like? -->

## 🎯 Claude Instructions

### Specific Actions Requested
- [ ] Analyze existing code
- [ ] Implement new functionality
- [ ] Fix identified bugs
- [ ] Add test coverage
- [ ] Update documentation
- [ ] Review and suggest improvements
- [ ] Other: _______________

### Areas of Focus
```bash
# Files/directories that need attention
src/pyforge_cli/converters/
src/pyforge_cli/main.py
tests/

# Specific functions/classes if known
class ConverterName
function_name()
```

### Requirements & Constraints
- **Code Style**: Follow existing project conventions
- **Testing**: Include appropriate test coverage
- **Documentation**: Update relevant docs
- **Backwards Compatibility**: Maintain existing API
- **Performance**: Consider performance implications

## 📋 Task Breakdown (for Claude)

### Investigation Phase
- [ ] Understand the request and requirements
- [ ] Analyze existing codebase and relevant files
- [ ] Identify dependencies and related components
- [ ] Review current test coverage

### Planning Phase
- [ ] Create detailed implementation plan
- [ ] Identify potential risks or challenges
- [ ] Plan testing strategy
- [ ] Consider documentation updates needed

### Implementation Phase
- [ ] Implement core functionality
- [ ] Add appropriate error handling
- [ ] Ensure code follows project standards
- [ ] Add comprehensive logging/debugging

### Testing Phase
- [ ] Create unit tests for new functionality
- [ ] Add integration tests if needed
- [ ] Test edge cases and error conditions
- [ ] Verify backwards compatibility

### Documentation Phase
- [ ] Update code comments
- [ ] Update API documentation
- [ ] Update user documentation if needed
- [ ] Update changelog/release notes

## 🔍 Additional Context

### Related Issues
- Related to: #
- Depends on: #
- Blocks: #

### Files to Focus On
```bash
# Primary files
src/pyforge_cli/

# Test files
tests/

# Documentation
docs/
README.md
```

### Environment Details
- **Python Version**: 3.10+
- **Key Dependencies**: pandas, pyarrow, etc.
- **Target Platforms**: Windows, macOS, Linux

## 🚀 To Activate Claude Assistance

**@claude** - Please help with this task using the information provided above.

## ✅ Success Criteria

- [ ] Task completed as specified
- [ ] Code follows project conventions
- [ ] Appropriate test coverage added
- [ ] Documentation updated if needed
- [ ] No regressions introduced
- [ ] All CI checks pass

---

**Note**: Claude will automatically respond to this issue when mentioned with @claude and will provide:
- Analysis of the request
- Implementation plan
- Code changes with explanations
- Test coverage
- Documentation updates

**Expected Response Time**: Claude typically responds within a few minutes during active hours.